/* Copyright 2013, Martin Koller, kollix@aon.at

  This file is part of airsyncDownload.

  airsyncDownload is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  airsyncDownload is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with airsyncDownload.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <QObject>
#include <QNetworkAccessManager>
#include <QNetworkRequest>
#include <QNetworkReply>
#include <QEventLoop>
#include <QUrl>

class Session : public QObject
{
  Q_OBJECT

  public:
    Session(const QString &server, const QString &domain,
            const QString &username, const QString &password, const QString &uniqueDeviceId);

    QByteArray sendCommand(const QByteArray &cmd, const QByteArray &data);

    QByteArray post(QNetworkRequest req, const QByteArray &data);

    // get OPTIONS and print them
    void options();

    static bool dataToWbXml(const QByteArray &data, QByteArray &result);
    static bool dataFromWbXml(const QByteArray &data, QByteArray &result);

    void setPolicyKey(uint key) { policyKey = key; }

    void setDebug(bool d) { debug = d; }

  private slots:
    void sslErrors(QNetworkReply *reply, const QList<QSslError> &errors);

  private:
    QNetworkAccessManager *nam;
    QEventLoop *eventLoop;

    QUrl serverUrl;
    QByteArray loginBase64;
    uint policyKey;
    bool debug;
    bool wroteSslWarning;
};
